@@ -14,6 +14,8 @@ Usage : sconet.py [OPTION] [ARGS]
 -t, --type               : Type d'importation choisit ( 'maj' ou 'full' )
                            en complément de --import (Not implemented yet)
 
+-u , --user              : utilisateur qui lance l'importation (default=admin)
+
 Ex :
 1) importation.py --parse sconet /tmp/extraction-00124-sconet.register
 - Lie les fichiers d'importation sconet eleve depuis la conf dans /tmp/extraction-00124-sconet.register
@@ -25,7 +27,6 @@ import getopt, sys
 import json
 from os.path import isfile
 
-from scribe import entlogin
 from scribe.eoleldap import Ldap
 from scribe.ldapconf import SUPPORT_ETAB
 from scribe.eoletools import nscd_start, nscd_stop
@@ -52,8 +53,8 @@ def main():
     """
     try:
         opts, args = getopt.getopt(sys.argv[1:],
-                                   "t:p:i",
-                                   ["type=","parse=","import"])
+                                   "t:p:i:u",
+                                   ["type=","parse=","import","user="])
     except getopt.GetoptError, err:
         print(err)
         usage()
@@ -61,6 +62,7 @@ def main():
     action = None
     data_type = None
     import_type = None
+    user = config.DEFAULT_USER
     for option, value in opts:
         if option in ('-h', '--help'):
             usage()
@@ -73,6 +75,8 @@ def main():
             break
         elif option in ('-i', '--import'):
             action = 'import'
+        elif option in ('-u', '--user'):
+            user = value
         else:
             usage()
             print("Option inconnue")
@@ -110,7 +114,7 @@ def main():
             importer.log_err("Il manque le type d'import maj/annuel")
         else:
             importer.import_type = import_type
-        importer.do_import()
+        importer.do_import(user=user)
 
 class Parser(Logger):
     """
@@ -337,10 +341,11 @@ class Importer(Logger):
         self.store = init_store(config.DB_DIR, delete=False)
         self.end_msg = "FIN DE L'IMPORTATION DE COMPTES"
 
-    def do_import(self):
+    def do_import(self, user=config.DEFAULT_USER):
         """
             Importe des données dans le ldap du scribe
         """
+        self.user = user
         try:
             importlog.add_lock()
             if self.category_type == 'eleve':
@@ -363,6 +368,7 @@ class Importer(Logger):
         self.log("Arrêt de nscd...<br />")
         importlog.debuglog("Arrêt de nscd...", title=True)
         nscd_stop()
+        self.log_ok()
         connexion = Ldap()
         connexion.connect()
         if self.import_type != 'maj' :
@@ -402,7 +408,7 @@ class Importer(Logger):
             self.log_err(error=error)
         try:
             self.log("Intégration des élèves...")
-            writer.write_eleve(storage=self.store, connexion=connexion, etab=etab)
+            writer.write_eleve(storage=self.store, connexion=connexion, etab=etab, current_ead_user=self.user)
             self.log_ok()
         except Exception, error:
             self.log_err(error=error)
@@ -410,20 +416,16 @@ class Importer(Logger):
             try:
                 self.log("Intégration des responsables...")
                 writer.write_responsable(storage=self.store,
-                                         connexion=connexion)
+                                         connexion=connexion, current_ead_user=self.user)
                 self.log_ok()
             except Exception, error:
                 self.log_err(error=error)
         else:
-            self.log("NB : Importation sans responsable")
+            self.log("NB : Importation sans responsable<br>")
+        self.log("Synchronisation des partages Samba...")
+        writer.write_samba(connexion)
+        self.log_ok()
         connexion.close()
-        try:
-            self.log("Affectation des identifiants uniques ENT...")
-            entlogin.entlogin_eleves()
-            entlogin.entlogin_responsables()
-            self.log_ok()
-        except Exception, error:
-            self.log_err(error=error)
         try:
             self.log("Démarrage de nscd...")
             importlog.debuglog("Démarrage de nscd...", title=True)
@@ -432,7 +434,7 @@ class Importer(Logger):
         except Exception, error:
             self.log_err(error=error)
         self.log_end()
-        importlog.end_importation('EAD')
+        importlog.end_importation('EAD', self.user)
 
     def do_import_personnel(self, enseignants=True):
         """
@@ -441,6 +443,7 @@ class Importer(Logger):
         self.log("Arrêt de nscd...<br />")
         importlog.debuglog("Arrêt de nscd...", title=True)
         nscd_stop()
+        self.log_ok()
         connexion = Ldap()
         connexion.connect()
         if SUPPORT_ETAB:
@@ -482,7 +485,7 @@ class Importer(Logger):
             try:
                 self.log("Intégration des enseignants...<br />")
                 writer.write_enseignant(storage=self.store, connexion=connexion,
-                                        etab=etab)
+                                        etab=etab, current_ead_user=self.user)
                 self.log_ok()
             except Exception, error:
                 self.log_err(error=error)
@@ -496,24 +499,21 @@ class Importer(Logger):
         try:
             self.log("Intégration des personnels administratifs...<br />")
             writer.write_administratif(storage=self.store, connexion=connexion,
-                                       etab=etab)
+                                       etab=etab, current_ead_user=self.user)
             self.log_ok()
         except Exception, error:
             self.log_err(error=error)
+        self.log("Synchronisation des partages Samba...")
+        writer.write_samba(connexion)
+        self.log_ok()
         # fin du mode connecté
         connexion.close()
-        try:
-            self.log("Affectation des identifiants uniques ENT...<br />")
-            entlogin.entlogin_enseignants()
-            entlogin.entlogin_administratifs()
-            self.log_ok()
-        except Exception, error:
-            self.log_err(error=error)
         self.log("Démarrage de nscd...<br />")
         importlog.debuglog("Démarrage de nscd...", title=True)
         nscd_start()
+        self.log_ok()
         self.log_end()
-        importlog.end_importation('EAD')
+        importlog.end_importation('EAD', self.user)
 
     def do_import_invite(self):
         """
@@ -524,20 +524,14 @@ class Importer(Logger):
         connexion.connect()
         try:
             self.log("Intégration des comptes invités...<br />")
-            writer.write_invite(storage=self.store, connexion=connexion)
+            writer.write_invite(storage=self.store, connexion=connexion, current_ead_user=self.user)
             self.log_ok()
         except Exception, error:
             self.log_err(error=error)
         # fin du mode connecté
         connexion.close()
-        try:
-            self.log("Affectation des identifiants uniques ENT...<br />")
-            entlogin.entlogin_autres()
-            self.log_ok()
-        except Exception, error:
-            self.log_err(error=error)
         self.log_end()
-        importlog.end_importation('EAD')
+        importlog.end_importation('EAD', self.user)
 
 if __name__ == '__main__':
     main()
